@@ -323,11 +323,11 @@ eel_caption_table_new (guint num_rows)
 
 void
 eel_caption_table_set_row_info (EelCaptionTable *caption_table,
-				     guint row,
-				     const char* label_text,
-				     const char* entry_text,
-				     gboolean entry_visibility,
-				     gboolean entry_readonly)
+				guint row,
+				const char* label_text,
+				const char* entry_text,
+				gboolean entry_visibility,
+				gboolean entry_readonly)
 {
 	g_return_if_fail (caption_table != NULL);
 	g_return_if_fail (EEL_IS_CAPTION_TABLE (caption_table));
@@ -338,6 +338,12 @@ eel_caption_table_set_row_info (EelCaptionTable *caption_table,
 	gtk_entry_set_text (GTK_ENTRY (caption_table->detail->entries[row]), entry_text);
 	gtk_entry_set_visibility (GTK_ENTRY (caption_table->detail->entries[row]), entry_visibility);
 	gtk_widget_set_sensitive (caption_table->detail->entries[row], !entry_readonly);
+	if (!entry_visibility) {
+		AtkObject *accessible;
+
+		accessible = gtk_widget_get_accessible (caption_table->detail->entries[row]);
+		atk_object_set_role (accessible, ATK_ROLE_PASSWORD_TEXT);
+	}
 }
 
 void
