@@ -3,7 +3,7 @@
 #include <eel/eel-caption-table.h>
 #include <eel/eel-radio-button-group.h>
 #include <eel/eel-string-picker.h>
-#include <eel/eel-text-caption.h>
+#include <eel/eel-stock-dialogs.h>
 #include <gtk/gtk.h>
 #include <libgnomeui/gnome-ui-init.h>
 
@@ -15,7 +15,7 @@ create_pixbuf (const char *name)
 
 	g_return_val_if_fail (name != NULL, NULL);
 
-	path = g_strdup_printf ("/gnome/GNOME2/share/pixmaps/nautilus/%s", name);
+	path = g_strdup_printf ( DATADIR "/pixmaps/nautilus/%s", name);
 	
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	g_free (path);
@@ -29,15 +29,13 @@ static void test_radio_group                     (void);
 static void test_radio_group_horizontal          (void);
 static void test_caption_table                   (void);
 static void test_string_picker                   (void);
-static void test_text_caption                    (void);
+static void test_ok_dialog                       (void);
 
 /* Callbacks */
 static void test_radio_changed_callback          (GtkWidget *button_group,
 						  gpointer   user_data);
 static void string_picker_changed_callback       (GtkWidget *string_picker,
 						  gpointer   user_data);
-static void text_caption_changed_callback        (GtkWidget *text_caption,
-						  gpointer   user_data);
 static void test_caption_table_activate_callback (GtkWidget *button_group,
 						  gint       active_index,
 						  gpointer   user_data);
@@ -53,7 +51,7 @@ main (int argc, char * argv[])
 	test_radio_group_horizontal ();
 	test_caption_table ();
 	test_string_picker ();
-	test_text_caption ();
+	test_ok_dialog ();
 
 	gtk_main ();
 
@@ -103,6 +101,7 @@ test_radio_group (void)
 	GtkWidget *window;
 	GtkWidget *buttons;
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), "radio group test");
 
 	buttons = eel_radio_button_group_new (FALSE);
 
@@ -127,6 +126,7 @@ test_radio_group_horizontal (void)
 	GtkWidget *buttons;
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), "horizontal radio group test");
 
 	buttons = eel_radio_button_group_new (TRUE);
 
@@ -151,6 +151,7 @@ test_caption_table (void)
 	GtkWidget * table;
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), "caption table test");
 
 	table = eel_caption_table_new (4);
 
@@ -202,6 +203,7 @@ test_string_picker (void)
 	EelStringList	*font_list;
 	
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), "string picker test");
 
 	picker = eel_string_picker_new ();
 	
@@ -231,30 +233,6 @@ test_string_picker (void)
 	gtk_widget_show_all (window);
 }
 
-static void
-test_text_caption (void)
-{
-	GtkWidget		*window;
-	GtkWidget		*picker;
-	
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-	picker = eel_text_caption_new ();
-	
-	eel_caption_set_title_label (EEL_CAPTION (picker), "Home Page:");
-
-	eel_text_caption_set_text (EEL_TEXT_CAPTION (picker), "file:///tmp");
-	
-	gtk_container_add (GTK_CONTAINER (window), picker);
-	
-	g_signal_connect (picker,
-			    "changed",
-			    G_CALLBACK (text_caption_changed_callback),
-			    (gpointer) NULL);
-
-	gtk_widget_show_all (window);
-}
-
 static void
 string_picker_changed_callback (GtkWidget *string_picker, gpointer user_data)
 {
@@ -270,21 +248,6 @@ string_picker_changed_callback (GtkWidget *string_picker, gpointer user_data)
 	g_free (text);
 }
 
-static void
-text_caption_changed_callback (GtkWidget *text_caption, gpointer user_data)
-{
-	char	  *text;
-
-	g_assert (text_caption != NULL);
-	g_assert (EEL_IS_TEXT_CAPTION (text_caption));
-
-	text = eel_text_caption_get_text (EEL_TEXT_CAPTION (text_caption));
-
-	g_print ("text_caption_changed_callback(%s)\n", text);
-	
-	g_free (text);
-}
-
 static void
 test_radio_changed_callback (GtkWidget *buttons, gpointer user_data)
 {
@@ -302,3 +265,16 @@ test_caption_table_activate_callback (GtkWidget  *button_group,
 {
 	g_print ("test_caption_table_activate_callback (active_index=%d)\n", active_index);
 }
+
+static void
+test_ok_dialog (void)
+{
+	GtkDialog *dialog;
+
+	dialog = eel_show_info_dialog ("Some test information",
+				       "the dialog title",
+				       NULL);
+	gtk_dialog_run (dialog);
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+}
